@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12130 2020-04-29 00:28:40Z Trista $
+# $Id: __init__.py 12131 2020-04-29 00:43:31Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-29 08:28:40 +0800 (週三, 29 四月 2020) $
-# $Revision: 12130 $
+# $Date: 2020-04-29 08:43:31 +0800 (週三, 29 四月 2020) $
+# $Revision: 12131 $
 
 from __future__ import print_function
 
@@ -436,11 +436,11 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                     'PASSWORD': _get('DATABASE_PASSWORD'),
                     'HOST': _get('DATABASE_HOST'),
                     'PORT': _get('DATABASE_PORT'),
-                    if 'OPTIONS' in _get:
-                        'OPTIONS': _get('OPTIONS') ,
                 },
             },
         }
+        if 'OPTIONS' in _get:
+            databaseDefaults['DATABASES']['default']['OPTIONS'] = _get('OPTIONS')
         databaseDefaults.update(dd)
 
     update(settingsDict, databaseDefaults)
